@@ -137,6 +137,7 @@ def setup(settings_path=None, **settings_patches):
     # Create homebase
     print section_title('Deploy target is: %s' % beanstalk_stack_base)
     local('mkdir -p %s' % beanstalk_stack_base)
+    local('mkdir -p %s' % os.path.join(beanstalk_stack_base, 'apps'))
     local('mkdir -p %s' % os.path.join(beanstalk_stack_base, 'global-logs'))
     local('mkdir -p %s' % os.path.join(beanstalk_stack_base, 'confs'))
     local('echo "[]" > %s' % app_ports_path())
@@ -379,10 +380,12 @@ def app_info(project_name, settings_path=None, **settings_patches):
 
     if beanstalk_settings.get('USE_JSON', False):
         result = {
-            'base': project_base_path(project_name),
-            'source': project_source_path(project_name),
-            'logs': project_logs_path(project_name),
-            'venv': project_venv_path(project_name),
+            'path': {
+                'base': project_base_path(project_name),
+                'source': project_source_path(project_name),
+                'logs': project_logs_path(project_name),
+                'venv': project_venv_path(project_name),
+            },
             'uwsgi': {
                 'port': uwsgi_port,
             },
